==> vtigercrm-5.3.0p0.tgz: modules/Potentials/language/es_mx.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 ********************************************************************************
*  Module       : Potentials
*  Language     : Español
*  Version      : 504
*  Created Date : 2007-03-30
*  Author       : Rafael Soler
*  Last change  : 2008-09-20
*  Author       : Joe Bordes JPL TSolucio, S.L.
 *  Author       : Francisco Hernandez Odin Consultores www.odin.mx
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Oportunidades',
'LBL_MODULE_TITLE'=>'Oportunidades: Inicio',
'LBL_SEARCH_FORM_TITLE'=>'Buscar Oportunidades',
'LBL_LIST_FORM_TITLE'=>'Lista de Oportunidades',
'LBL_OPPORTUNITY_NAME'=>'Oportunidad:',
'LBL_OPPORTUNITY'=>'Oportunidad:',
'LBL_NAME'=>'Oportunidad',
'LBL_INVITEE'=>'Contactos',
'LBL_LIST_OPPORTUNITY_NAME'=>'Oportunidad',
'LBL_LIST_ACCOUNT_NAME'=>'Cuenta',
'LBL_PRODUCT_NAME'=>'Producto',
'LBL_LIST_AMOUNT'=>'Importe',
'LBL_LIST_DATE_CLOSED'=>'Fecha estimada de cierre',
'LBL_LIST_SALES_STAGE'=>'Etapa de Venta',

'LBL_OPPORTUNITY_NAME'=>'Oportunidad:',
'LBL_ACCOUNT_NAME'=>'Cuenta:',
'LBL_AMOUNT'=>'Importe:',
'LBL_DATE_CLOSED'=>'Fecha estimada de cierre:',
'LBL_TYPE'=>'Tipo:',
'LBL_NEXT_STEP'=>'Siguiente paso:',
'LBL_LEAD_SOURCE'=>'Origen del Prospecto:',
'LBL_SALES_STAGE'=>'Etapa de Venta:',
'LBL_PROBABILITY'=>'Probabilidad (%):',
'LBL_DESCRIPTION'=>'Descripción:',
'LBL_OPPORTUNITY_INFORMATION'=>'Información de Oportunidad:',
'LBL_DESCRIPTION_INFORMATION'=>'Información Adicional:',
'LBL_CUSTOM_INFORMATION'=>'Información Personalizada',

'LBL_NEW_FORM_TITLE'=>'Nueva Oportunidad',

'ERR_DELETE_RECORD'=>'Debe especificar un registro para eliminar la oportunidad.',
'LBL_TOP_OPPORTUNITIES'=>'Mis Oportunidades abiertas',

'NTC_REMOVE_OPP_CONFIRMATION'=>'¿Está seguro de eliminar este contacto de esta oportunidad?',

'NTC_NONE_SCHEDULED'=>'Nada',

'LBL_SELECT_OPPOPTUNITY'=>'Seleccionar Oportunidad',
'LBL_GENERAL_INFORMATION'=>'Información General',


//for v4 release added
'LBL_NEW_POTENTIAL'=>'Nueva Oportunidad',
'LBL_POTENTIAL_TITLE'=>'Oportunidades',

'LBL_NEW_TASK'=>'Nueva Tarea',
'LBL_TASK_TITLE'=>'Tareas',
'LBL_NEW_CALL'=>'Nueva Llamada',
'LBL_CALL_TITLE'=>'Llamadas',
'LBL_NEW_MEETING'=>'Nueva Reunión',
'LBL_MEETING_TITLE'=>'Reuniones',
'LBL_NEW_EMAIL'=>'Nuevo Email',
'LBL_EMAIL_TITLE'=>'Emails',
'LBL_NEW_NOTE'=>'Nuevo Documento',
'LBL_NOTE_TITLE'=>'Documentos',

'LBL_NEW_ATTACHMENT'=>'Nuevo Adjunto',
'LBL_ATTACHMENT_TITLE'=>'Adjuntos',

'LBL_NEW_CONTACT'=>'Nuevo Contacto',
'LBL_CONTACT_TITLE'=>'Contactos',

//Added vtiger_fields after RC1 - Release
'LBL_ALL'=>'Todas',
'LBL_WON'=>'Ganadas',
'LBL_LOST'=>'Perdidas',
'LBL_VALUE_PROPOSITION'=>'Cotización',
'LBL_PROSPECTING'=>'En Analisis',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Herramientas de Oportunidades',
//Added for 4GA
'Potential Name'=>'Oportunidad',
'Amount'=>'Importe',
'Account Name'=>'Cuenta',
'Currency'=>'Moneda',
'Expected Close Date'=>'Fecha estimada de cierre',
'Opportunity Type'=>'Tipo de Oportunidad',
'Type'=>'Tipo',
'Next Step'=>'Siguiente Paso',
'Lead Source'=>'Origen del Prospecto',
'Sales Stage'=>'Fase de Venta',
'Assigned To'=>'Asignado a',
'Probability'=>'Probabilidad',
'Campaign Source'=>'Campaña Origen',
'Description'=>'Descripción',
'Created Time'=>'Fecha de Creación',
'Modified Time'=>'Última Modificación',
//Added for 4.2 Release -- CustomView
'Potential'=>'Oportunidad',
'Expected Close'=>'Fecha estimada de cierre',

//Added for Existing Picklist Strings

'Prospecting'=>'Investigando',
'Qualification'=>'Calificando',
'Needs Analysis'=>'Necesita Análisis',
'Value Proposition'=>'Propuesta de Evaluación',
'Id. Decision Makers'=>'Identificando Quien Decide',
'Perception Analysis'=>'Análisis',
'Proposal/Price Quote'=>'Cotización Propuesta',
'Negotiation/Review'=>'Negociando/Revisando',
'Closed Won'=>'Cerrada-Ganada',
'Closed Lost'=>'Cerrada-Perdida',

'Cold Call'=>'Llamada',
'Existing Customer'=>'Cliente',
'Self Generated'=>'Autogenerada',
'Employee'=>'Trabajador',
'Partner'=>'Socio',
'Public Relations'=>'Relaciones Públicas',
'Direct Mail'=>'Mailing',
'Conference'=>'Conferencia',
'Trade Show'=>'Feria',
'Web Site'=>'Web Site',
'Word of mouth'=>'Boca a Boca',
'Other'=>'Otro',

'--None--'=>'-----',
'Existing Business'=>'Negocio Existente',
'New Business'=>'Nuevo Negocio',
'Related To'=>'Relacionado con',

// Added after 5.0.4 GA

// Module Sequence Numbering
'Potential No' => 'Núm. Oportunidad',
// END

);

?>

==> vtigercrm-5.4.0.tgz: modules/Potentials/language/es_mx.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 ********************************************************************************
*  Module       : Potentials
*  Language     : Español
*  Version      : 5.4.0
*  Created Date : 2007-03-30
*  Author       : Rafael Soler
*  Last change  : 2012-02-27
*  Author       : Joe Bordes JPL TSolucio, S.L.
 *  Author       : Francisco Hernandez Odin Consultores www.odin.mx
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Oportunidades',
'LBL_MODULE_TITLE'=>'Oportunidades: Inicio',
'LBL_SEARCH_FORM_TITLE'=>'Buscar Oportunidades',
'LBL_LIST_FORM_TITLE'=>'Lista de Oportunidades',
'LBL_OPPORTUNITY_NAME'=>'Oportunidad:',
'LBL_OPPORTUNITY'=>'Oportunidad:',
'LBL_NAME'=>'Oportunidad',
'LBL_INVITEE'=>'Contactos',
'LBL_LIST_OPPORTUNITY_NAME'=>'Oportunidad',
'LBL_LIST_ACCOUNT_NAME'=>'Cuenta',
'LBL_PRODUCT_NAME'=>'Producto',
'LBL_LIST_AMOUNT'=>'Importe',
'LBL_LIST_DATE_CLOSED'=>'Fecha estimada de cierre',
'LBL_LIST_SALES_STAGE'=>'Etapa de Venta',

'LBL_OPPORTUNITY_NAME'=>'Oportunidad:',
'LBL_ACCOUNT_NAME'=>'Cuenta:',
'LBL_AMOUNT'=>'Importe:',
'LBL_DATE_CLOSED'=>'Fecha estimada de cierre:',
'LBL_TYPE'=>'Tipo:',
'LBL_NEXT_STEP'=>'Siguiente paso:',
'LBL_LEAD_SOURCE'=>'Origen del Prospecto:',
'LBL_SALES_STAGE'=>'Etapa de Venta:',
'LBL_PROBABILITY'=>'Probabilidad (%):',
'LBL_DESCRIPTION'=>'Descripción:',
'LBL_OPPORTUNITY_INFORMATION'=>'Información de Oportunidad:',
'LBL_DESCRIPTION_INFORMATION'=>'Información Adicional:',
'LBL_CUSTOM_INFORMATION'=>'Información Personalizada',

'LBL_NEW_FORM_TITLE'=>'Nueva Oportunidad',

'ERR_DELETE_RECORD'=>'Debe especificar un registro para eliminar la oportunidad.',
'LBL_TOP_OPPORTUNITIES'=>'Mis Oportunidades abiertas',

'NTC_REMOVE_OPP_CONFIRMATION'=>'¿Está seguro de eliminar este contacto de esta oportunidad?',

'NTC_NONE_SCHEDULED'=>'Nada',

'LBL_SELECT_OPPOPTUNITY'=>'Seleccionar Oportunidad',
'LBL_GENERAL_INFORMATION'=>'Información General',


//for v4 release added
'LBL_NEW_POTENTIAL'=>'Nueva Oportunidad',
'LBL_POTENTIAL_TITLE'=>'Oportunidades',

'LBL_NEW_TASK'=>'Nueva Tarea',
'LBL_TASK_TITLE'=>'Tareas',
'LBL_NEW_CALL'=>'Nueva Llamada',
'LBL_CALL_TITLE'=>'Llamadas',
'LBL_NEW_MEETING'=>'Nueva Reunión',
'LBL_MEETING_TITLE'=>'Reuniones',
'LBL_NEW_EMAIL'=>'Nuevo Email',
'LBL_EMAIL_TITLE'=>'Emails',
'LBL_NEW_NOTE'=>'Nuevo Documento',
'LBL_NOTE_TITLE'=>'Documentos',

'LBL_NEW_ATTACHMENT'=>'Nuevo Adjunto',
'LBL_ATTACHMENT_TITLE'=>'Adjuntos',

'LBL_NEW_CONTACT'=>'Nuevo Contacto',
'LBL_CONTACT_TITLE'=>'Contactos',

//Added vtiger_fields after RC1 - Release
'LBL_ALL'=>'Todas',
'LBL_WON'=>'Ganadas',
'LBL_LOST'=>'Perdidas',
'LBL_VALUE_PROPOSITION'=>'Cotización',
'LBL_PROSPECTING'=>'En Analisis',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Herramientas de Oportunidades',
//Added for 4GA
'Potential Name'=>'Oportunidad',
'Amount'=>'Importe',
'Account Name'=>'Cuenta',
'Currency'=>'Moneda',
'Expected Close Date'=>'Fecha estimada de cierre',
'Opportunity Type'=>'Tipo de Oportunidad',
'Type'=>'Tipo',
'Next Step'=>'Siguiente Paso',
'Lead Source'=>'Origen del Prospecto',
'Sales Stage'=>'Fase de Venta',
'Assigned To'=>'Asignado a',
'Probability'=>'Probabilidad',
'Campaign Source'=>'Campaña Origen',
'Description'=>'Descripción',
'Created Time'=>'Fecha de Creación',
'Modified Time'=>'Última Modificación',
//Added for 4.2 Release -- CustomView
'Potential'=>'Oportunidad',
'Expected Close'=>'Fecha estimada de cierre',

//Added for Existing Picklist Strings

'Prospecting'=>'Investigando',
'Qualification'=>'Calificando',
'Needs Analysis'=>'Necesita Análisis',
'Value Proposition'=>'Propuesta de Evaluación',
'Id. Decision Makers'=>'Identificando Quien Decide',
'Perception Analysis'=>'Análisis',
'Proposal/Price Quote'=>'Cotización Propuesta',
'Negotiation/Review'=>'Negociando/Revisando',
'Closed Won'=>'Cerrada-Ganada',
'Closed Lost'=>'Cerrada-Perdida',

'Cold Call'=>'Llamada',
'Existing Customer'=>'Cliente',
'Self Generated'=>'Autogenerada',
'Employee'=>'Trabajador',
'Partner'=>'Socio',
'Public Relations'=>'Relaciones Públicas',
'Direct Mail'=>'Mailing',
'Conference'=>'Conferencia',
'Trade Show'=>'Feria',
'Web Site'=>'Web Site',
'Word of mouth'=>'Boca a Boca',
'Other'=>'Otro',

'--None--'=>'-----',
'Existing Business'=>'Negocio Existente',
'New Business'=>'Nuevo Negocio',
'Related To'=>'Relacionado con',

// Added after 5.0.4 GA

// Module Sequence Numbering
'Potential No' => 'Núm. Oportunidad',
'Potentials ID' => 'Id Oportunidad',
// END

);

?>
